@@ -13,8 +13,10 @@ from discord import (
     Role,
     TextChannel,
     Thread,
+    ThreadMember,
     User,
 )
+from discord.abc import GuildChannel
 from discord.ext import commands
 from discord.ext.commands import Bot, Cog, Context
 
@@ -36,7 +38,7 @@ from commanderbot.lib import (
     UnsupportedDatabaseOptions,
     checks,
 )
-from commanderbot.lib.utils import is_bot
+from commanderbot.lib.utils import is_bot, parse_json_path, parse_json_path_op
 
 
 def make_automod_store(bot: Bot, cog: Cog, options: AutomodOptions) -> AutomodStore:
@@ -112,6 +114,21 @@ class AutomodCog(Cog, name="commanderbot.ext.automod"):
         if not is_bot(self.bot, member):
             return self.state[member.guild]
 
+    def _guild_state_for_channel(
+        self, channel: GuildChannel
+    ) -> Optional[AutomodGuildState]:
+        if isinstance(channel, TextChannel | Thread):
+            return self.state[channel.guild]
+
+    def _guild_state_for_thread(self, thread: Thread) -> Optional[AutomodGuildState]:
+        if (parent := thread.parent) and (guild := parent.guild):
+            return self.state[guild]
+
+    def _guild_state_for_thread_member(
+        self, member: ThreadMember
+    ) -> Optional[AutomodGuildState]:
+        return self._guild_state_for_thread(member.thread)
+
     def _guild_state_for_channel_user(
         self, channel: MessageableChannel, user: User
     ) -> Optional[AutomodGuildState]:
@@ -187,6 +204,78 @@ class AutomodCog(Cog, name="commanderbot.ext.automod"):
                 member=cast(Member, user),
             )
 
+    @Cog.listener()
+    async def on_guild_channel_create(self, channel: GuildChannel):
+        # https://discordpy.readthedocs.io/en/stable/api.html?highlight=events#discord.on_guild_channel_create
+        if guild_state := self._guild_state_for_channel(channel):
+            await guild_state.on_channel_create(
+                channel=cast(TextChannel | Thread, channel),
+            )
+
+    @Cog.listener()
+    async def on_guild_channel_delete(self, channel: GuildChannel):
+        # https://discordpy.readthedocs.io/en/stable/api.html?highlight=events#discord.on_guild_channel_delete
+        if guild_state := self._guild_state_for_channel(channel):
+            await guild_state.on_channel_delete(
+                channel=cast(TextChannel | Thread, channel),
+            )
+
+    @Cog.listener()
+    async def on_guild_channel_update(self, before: GuildChannel, after: GuildChannel):
+        # https://discordpy.readthedocs.io/en/stable/api.html?highlight=events#discord.on_guild_channel_update
+        if guild_state := self._guild_state_for_channel(after):
+            await guild_state.on_channel_update(
+                before=cast(TextChannel | Thread, before),
+                after=cast(TextChannel | Thread, after),
+            )
+
+    @Cog.listener()
+    async def on_thread_join(self, thread: Thread):
+        # https://discordpy.readthedocs.io/en/master/api.html#discord.on_thread_join
+        # NOTE Blame the official Discord API for this jank work-around.
+        # From the discord.py docs:
+        # > Note that from the API’s perspective there is no way to differentiate
+        # > between a thread being created or the bot joining a thread.
+        # So what we do is we check the `me` property of the thread to determine whether
+        # we're a member of it, and use that to determine how to proceed.
+        if guild_state := self._guild_state_for_thread(thread):
+            # If we're a member of the thread, we must've just joined it.
+            if thread.me:
+                await guild_state.on_thread_join(thread)
+            # Otherwise, it must be a newly-created thread.
+            else:
+                await guild_state.on_thread_create(thread)
+
+    @Cog.listener()
+    async def on_thread_remove(self, thread: Thread):
+        # https://discordpy.readthedocs.io/en/master/api.html#discord.on_thread_remove
+        if guild_state := self._guild_state_for_thread(thread):
+            await guild_state.on_thread_remove(thread)
+
+    @Cog.listener()
+    async def on_thread_delete(self, thread: Thread):
+        # https://discordpy.readthedocs.io/en/master/api.html#discord.on_thread_delete
+        if guild_state := self._guild_state_for_thread(thread):
+            await guild_state.on_thread_delete(thread)
+
+    @Cog.listener()
+    async def on_thread_update(self, before: Thread, after: Thread):
+        # https://discordpy.readthedocs.io/en/master/api.html#discord.on_thread_update
+        if guild_state := self._guild_state_for_thread(after):
+            await guild_state.on_thread_update(before, after)
+
+    @Cog.listener()
+    async def on_thread_member_join(self, member: ThreadMember):
+        # https://discordpy.readthedocs.io/en/master/api.html#discord.on_thread_member_join
+        if guild_state := self._guild_state_for_thread_member(member):
+            await guild_state.on_thread_member_join(member)
+
+    @Cog.listener()
+    async def on_thread_member_leave(self, member: ThreadMember):
+        # https://discordpy.readthedocs.io/en/master/api.html#discord.on_thread_member_leave
+        if guild_state := self._guild_state_for_thread_member(member):
+            await guild_state.on_thread_member_leave(member)
+
     @Cog.listener()
     async def on_member_join(self, member: Member):
         # https://discordpy.readthedocs.io/en/stable/api.html?highlight=events#discord.on_member_join
@@ -384,15 +473,21 @@ class AutomodCog(Cog, name="commanderbot.ext.automod"):
         name="show",
         brief="List and show automod rules.",
     )
-    async def cmd_automod_rules_show(self, ctx: GuildContext, *, query: str = ""):
+    async def cmd_automod_rules_show(self, ctx: GuildContext, query: str):
         await self.state[ctx.guild].show_rules(ctx, query)
 
     @cmd_automod_rules.command(
         name="print",
         brief="Print the code of an automod rule.",
     )
-    async def cmd_automod_rules_print(self, ctx: GuildContext, *, query: str):
-        await self.state[ctx.guild].print_rule(ctx, query)
+    async def cmd_automod_rules_print(
+        self,
+        ctx: GuildContext,
+        query: str,
+        path: Optional[str],
+    ):
+        parsed_path = parse_json_path(path) if path else None
+        await self.state[ctx.guild].print_rule(ctx, query, parsed_path)
 
     @cmd_automod_rules.command(
         name="add",
@@ -413,9 +508,17 @@ class AutomodCog(Cog, name="commanderbot.ext.automod"):
         brief="Modify an automod rule",
     )
     async def cmd_automod_rules_modify(
-        self, ctx: GuildContext, name: str, *, body: str
+        self,
+        ctx: GuildContext,
+        name: str,
+        path: str,
+        op: str,
+        *,
+        body: str,
     ):
-        await self.state[ctx.guild].modify_rule(ctx, name, body)
+        parsed_path = parse_json_path(path)
+        parsed_op = parse_json_path_op(op)
+        await self.state[ctx.guild].modify_rule(ctx, name, parsed_path, parsed_op, body)
 
     @cmd_automod_rules.command(
         name="enable",
